@@ -12,9 +12,9 @@ def remove_images(image: Image, tree: etree.Element):
         "Lab": (100, 0, 0), "HSV": (0, 0, 100)
     }[image.mode]
     draw = ImageDraw.Draw(image)
-    for image_region in tree.xpath('//{*}ImageRegion'):
-        for coords in image_region.xpath("./{*}Coords"):
-            coordstrings = [x.split(",") for x in coords.attrib["points"].split()]
-            poly = [(int(x[0]), int(x[1])) for x in coordstrings]
-            draw.polygon(poly, fill=white)
+    for image_region in tree.findall('.//{*}ImageRegion'):
+        coords = image_region.find("./{*}Coords")
+        coordstrings = [x.split(",") for x in coords.get("points").split()]
+        poly = [(int(x[0]), int(x[1])) for x in coordstrings]
+        draw.polygon(poly, fill=white)
     del draw
